import json
import logging
import os

from pyld import jsonld
from abb.env import env

_context_cache = None


def get_context_url():
    return "/%s" % env('CONTEXT_FILE')


def _load_document(url):
    global _context_cache

    if (url != get_context_url()) or not _context_cache:
        raise jsonld.JsonLdError("Document not cached: %s" % url)

    return _context_cache


def set_jsonld_context(filename=None):
    if filename is None:
        context_file = os.environ.get('CONTEXT_FILE')
        if not context_file:
            return

        filename = os.path.join(
            os.getcwd(),
            "static/",
            context_file
        )

    with open(filename, "r") as infile:
        document = json.load(infile)

    remote_doc = {
        'contextUrl': None,
        'documentUrl': get_context_url(),
        'document': document
    }

    global _context_cache
    _context_cache = remote_doc
    jsonld.set_document_loader(_load_document)
    logging.debug("JSON-LD context cached from %s" % filename)
